@@ -489,9 +489,14 @@ class Annotator:
                         isMatched = False
                         matchStart = -1
                         pivot = 0
+                        isFailed = False
                         for j in range(lo, hi):
                             if self.data[j][0] != 'd':
-                                continue
+                                # To activate MIDM pattern, the first instruction
+                                # after insertion in read should be D.
+                                isFailed = True
+                                break
+                                #continue
                             if matchStart == -1:
                                 matchStart = int(self.data[j][2])
                             if ins[pivot] == self.data[j][3]:
@@ -502,6 +507,9 @@ class Annotator:
                                 isMatched = True
                                 break
 
+                        if isFailed:
+                            continue
+
                         if isMatched:
                             if VERBOSITY > 1:
                                 log('insertion matches gap from left\n')
